@@ -39,7 +39,7 @@ PG_FUNCTION_INFO_V1(nvarchar2recv);
 static VarChar *
 nvarchar2_input(const char *s, size_t len, int32 atttypmod)
 {
-	VarChar		*result;		/* input data */
+	VarChar    *result;			/* input data */
 	size_t		maxlen;
 
 	maxlen = atttypmod - VARHDRSZ;
@@ -49,7 +49,8 @@ nvarchar2_input(const char *s, size_t len, int32 atttypmod)
 	 */
 	if (atttypmod >= (int32) VARHDRSZ && len > maxlen)
 	{
-		/* Verify that input length is within typmod limit.
+		/*
+		 * Verify that input length is within typmod limit.
 		 *
 		 * NOTE: blankspace is not truncated
 		 */
@@ -58,11 +59,11 @@ nvarchar2_input(const char *s, size_t len, int32 atttypmod)
 		if (mbmaxlen > maxlen)
 			ereport(ERROR,
 					(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-						errmsg("input value length is %zd; too long for type nvarchar2(%zd)", mbmaxlen , maxlen)));
+					 errmsg("input value length is %zd; too long for type nvarchar2(%zd)", mbmaxlen, maxlen)));
 	}
 
 	result = (VarChar *) cstring_to_text_with_len(s, size2int(len));
-	return  result;
+	return result;
 }
 
 /*
@@ -72,12 +73,12 @@ nvarchar2_input(const char *s, size_t len, int32 atttypmod)
 Datum
 nvarchar2in(PG_FUNCTION_ARGS)
 {
-	char	*s = PG_GETARG_CSTRING(0);
+	char	   *s = PG_GETARG_CSTRING(0);
 #ifdef NOT_USED
-	Oid		typelem = PG_GETARG_OID(1);
+	Oid			typelem = PG_GETARG_OID(1);
 #endif
-	int32	atttypmod = PG_GETARG_INT32(2);
-	VarChar	*result;
+	int32		atttypmod = PG_GETARG_INT32(2);
+	VarChar    *result;
 
 	result = nvarchar2_input(s, strlen(s), atttypmod);
 	PG_RETURN_VARCHAR_P(result);
@@ -93,7 +94,7 @@ nvarchar2in(PG_FUNCTION_ARGS)
 Datum
 nvarchar2out(PG_FUNCTION_ARGS)
 {
-	Datum   txt = PG_GETARG_DATUM(0);
+	Datum		txt = PG_GETARG_DATUM(0);
 
 	PG_RETURN_CSTRING(TextDatumGetCString(txt));
 }
@@ -109,10 +110,11 @@ nvarchar2recv(PG_FUNCTION_ARGS)
 #ifdef NOT_USED
 	Oid			typelem = PG_GETARG_OID(1);
 #endif
-	int32		atttypmod = PG_GETARG_INT32(2);	/* typmod of the receiving column */
-	VarChar		*result;
-	char		*str;							/* received data */
-	int			nbytes;							/* length in bytes of recived data */
+	int32		atttypmod = PG_GETARG_INT32(2); /* typmod of the receiving
+												 * column */
+	VarChar    *result;
+	char	   *str;			/* received data */
+	int			nbytes;			/* length in bytes of recived data */
 
 	str = pq_getmsgtext(buf, buf->len - buf->cursor, &nbytes);
 	result = nvarchar2_input(str, nbytes, atttypmod);
@@ -148,13 +150,13 @@ nvarchar2recv(PG_FUNCTION_ARGS)
 Datum
 nvarchar2(PG_FUNCTION_ARGS)
 {
-	VarChar		*source = PG_GETARG_VARCHAR_PP(0);
+	VarChar    *source = PG_GETARG_VARCHAR_PP(0);
 	int32		typmod = PG_GETARG_INT32(1);
 	bool		isExplicit = PG_GETARG_BOOL(2);
 	int32		len,
 				maxlen;
-	int		maxmblen;
-	char		*s_data;
+	int			maxmblen;
+	char	   *s_data;
 
 	len = VARSIZE_ANY_EXHDR(source);
 	s_data = VARDATA_ANY(source);
@@ -172,14 +174,15 @@ nvarchar2(PG_FUNCTION_ARGS)
 	/* error out if value too long unless it's an explicit cast */
 	if (!isExplicit)
 	{
-		/* if there is still data beyond maxmblen, error out
+		/*
+		 * if there is still data beyond maxmblen, error out
 		 *
 		 * Remember - no blankspace truncation on implicit cast
 		 */
 		if (len > maxmblen)
 			ereport(ERROR,
 					(errcode(ERRCODE_INVALID_PARAMETER_VALUE),
-						errmsg("input value too long for type nvarchar2(%d)", maxlen)));
+					 errmsg("input value too long for type nvarchar2(%d)", maxlen)));
 	}
 
 	PG_RETURN_VARCHAR_P((VarChar *) cstring_to_text_with_len(s_data, size2int(maxmblen)));
