@@ -26,11 +26,12 @@
 #include "orafce.h"
 #include "builtins.h"
 
-typedef struct {
-	List	*nodes;
-	int 	nnodes;
-	int	cnode;
-	char **values;
+typedef struct
+{
+	List	   *nodes;
+	int			nnodes;
+	int			cnode;
+	char	  **values;
 } tokensFctx;
 
 PG_FUNCTION_INFO_V1(plvlex_tokens);
@@ -91,7 +92,7 @@ static orafce_lexnode *
 compose(orafce_lexnode *a, orafce_lexnode *b)
 {
 	orafce_lexnode *result;
-	StringInfo sinfo;
+	StringInfo	sinfo;
 
 	sinfo = makeStringInfo();
 	result = NEWNODE(IDENT);
@@ -118,8 +119,8 @@ compose(orafce_lexnode *a, orafce_lexnode *b)
 static List *
 filterList(List *list, bool skip_spaces, bool qnames)
 {
-	List *result = NIL;
-	ListCell *cell;
+	List	   *result = NIL;
+	ListCell   *cell;
 	orafce_lexnode *a = NULL;
 	orafce_lexnode *dot = NULL;
 
@@ -129,7 +130,7 @@ filterList(List *list, bool skip_spaces, bool qnames)
 
 		if (qnames)
 		{
-			bool		isdot = (IsType(nd, OTHERS) && (nd->str[0] == '.'));
+			bool		isdot = (IsType(nd, OTHERS) && (nd->str) && (nd->str[0] == '.'));
 
 			if (IsType(nd, IDENT) && dot && a)
 			{
@@ -150,8 +151,8 @@ filterList(List *list, bool skip_spaces, bool qnames)
 		}
 
 		/* clean buffered values */
-		APPEND_NODE(result,a);
-		APPEND_NODE(result,dot);
+		APPEND_NODE(result, a);
+		APPEND_NODE(result, dot);
 
 		if (!(skip_spaces && IsType(nd, WHITESPACE)))
 		{
@@ -160,8 +161,8 @@ filterList(List *list, bool skip_spaces, bool qnames)
 	}
 
 	/* clean buffered values */
-	APPEND_NODE(result,a);
-	APPEND_NODE(result,dot);
+	APPEND_NODE(result, a);
+	APPEND_NODE(result, dot);
 
 	return result;
 }
@@ -169,19 +170,19 @@ filterList(List *list, bool skip_spaces, bool qnames)
 Datum
 plvlex_tokens(PG_FUNCTION_ARGS)
 {
-	FuncCallContext	   *funcctx;
-	TupleDesc			tupdesc;
-	AttInMetadata	   *attinmeta;
-	tokensFctx		   *fctx;
+	FuncCallContext *funcctx;
+	TupleDesc	tupdesc;
+	AttInMetadata *attinmeta;
+	tokensFctx *fctx;
 
 
-	if (SRF_IS_FIRSTCALL ())
+	if (SRF_IS_FIRSTCALL())
 	{
-		MemoryContext  oldcontext;
-		List *lexems;
-		text *src = PG_GETARG_TEXT_P(0);
-		bool skip_spaces = PG_GETARG_BOOL(1);
-		bool qnames = PG_GETARG_BOOL(2);
+		MemoryContext oldcontext;
+		List	   *lexems;
+		text	   *src = PG_GETARG_TEXT_P(0);
+		bool		skip_spaces = PG_GETARG_BOOL(1);
+		bool		qnames = PG_GETARG_BOOL(2);
 
 		orafce_sql_scanner_init(text_to_cstring(src));
 		if (orafce_sql_yyparse(&lexems) != 0)
@@ -189,70 +190,72 @@ plvlex_tokens(PG_FUNCTION_ARGS)
 
 		orafce_sql_scanner_finish();
 
-		funcctx = SRF_FIRSTCALL_INIT ();
-		oldcontext = MemoryContextSwitchTo (funcctx->multi_call_memory_ctx);
+		funcctx = SRF_FIRSTCALL_INIT();
+		oldcontext = MemoryContextSwitchTo(funcctx->multi_call_memory_ctx);
 
-		fctx = (tokensFctx*) palloc (sizeof (tokensFctx));
-		funcctx->user_fctx = (void *)fctx;
+		fctx = (tokensFctx *) palloc(sizeof(tokensFctx));
+		funcctx->user_fctx = (void *) fctx;
 
 		fctx->nodes = filterList(lexems, skip_spaces, qnames);
 		fctx->nnodes = list_length(fctx->nodes);
 		fctx->cnode = 0;
 
-		fctx->values = (char **) palloc (6 * sizeof (char *));
-		fctx->values  [0] = (char*) palloc (16 * sizeof (char));
-		fctx->values  [1] = (char*) palloc (1024 * sizeof (char));
-		fctx->values  [2] = (char*) palloc (16 * sizeof (char));
-		fctx->values  [3] = (char*) palloc (16 * sizeof (char));
-		fctx->values  [4] = (char*) palloc (255 * sizeof (char));
-		fctx->values  [5] = (char*) palloc (255 * sizeof (char));
+		fctx->values = (char **) palloc(6 * sizeof(char *));
+		fctx->values[0] = (char *) palloc(16 * sizeof(char));
+		fctx->values[2] = (char *) palloc(16 * sizeof(char));
+		fctx->values[3] = (char *) palloc(16 * sizeof(char));
+		fctx->values[4] = (char *) palloc(255 * sizeof(char));
+		fctx->values[5] = (char *) palloc(255 * sizeof(char));
 
 #if PG_VERSION_NUM >= 120000
 
-		tupdesc = CreateTemplateTupleDesc (6);
+		tupdesc = CreateTemplateTupleDesc(6);
 
 #else
 
-		tupdesc = CreateTemplateTupleDesc (6, false);
+		tupdesc = CreateTemplateTupleDesc(6, false);
 
 #endif
 
-		TupleDescInitEntry (tupdesc,  1, "start_pos", INT4OID, -1, 0);
-		TupleDescInitEntry (tupdesc,  2, "token",     TEXTOID, -1, 0);
-		TupleDescInitEntry (tupdesc,  3, "keycode",   INT4OID, -1, 0);
-		TupleDescInitEntry (tupdesc,  4, "class",     TEXTOID, -1, 0);
-		TupleDescInitEntry (tupdesc,  5, "separator", TEXTOID, -1, 0);
-		TupleDescInitEntry (tupdesc,  6, "mod",       TEXTOID, -1, 0);
+		TupleDescInitEntry(tupdesc, 1, "start_pos", INT4OID, -1, 0);
+		TupleDescInitEntry(tupdesc, 2, "token", TEXTOID, -1, 0);
+		TupleDescInitEntry(tupdesc, 3, "keycode", INT4OID, -1, 0);
+		TupleDescInitEntry(tupdesc, 4, "class", TEXTOID, -1, 0);
+		TupleDescInitEntry(tupdesc, 5, "separator", TEXTOID, -1, 0);
+		TupleDescInitEntry(tupdesc, 6, "mod", TEXTOID, -1, 0);
 
-		attinmeta = TupleDescGetAttInMetadata (tupdesc);
-		funcctx -> attinmeta = attinmeta;
+		attinmeta = TupleDescGetAttInMetadata(tupdesc);
+		funcctx->attinmeta = attinmeta;
 
-		MemoryContextSwitchTo (oldcontext);
+		MemoryContextSwitchTo(oldcontext);
 	}
 
-	funcctx = SRF_PERCALL_SETUP ();
-	fctx = (tokensFctx*) funcctx->user_fctx;
+	funcctx = SRF_PERCALL_SETUP();
+	fctx = (tokensFctx *) funcctx->user_fctx;
 
 	while (fctx->cnode < fctx->nnodes)
 	{
-		char **values;
-		Datum result;
-		HeapTuple tuple;
-		char *back_vals[6];
+		char	  **values;
+		Datum		result;
+		HeapTuple	tuple;
+		char	   *back_vals[6];
+
+		orafce_lexnode *nd = (orafce_lexnode *) list_nth(fctx->nodes, fctx->cnode++);
 
-		orafce_lexnode *nd = (orafce_lexnode*) list_nth(fctx->nodes, fctx->cnode++);
 		values = fctx->values;
 
 		back_vals[2] = values[2];
 		back_vals[4] = values[4];
 		back_vals[5] = values[5];
 
-		snprintf(values[0],    16, "%d", nd->lloc);
-		snprintf(values[1], 10000, "%s", SF(nd->str));
-		snprintf(values[2],    16, "%d", nd->keycode);
-		snprintf(values[3],    16, "%s", nd->classname);
-		snprintf(values[4],   255, "%s", SF(nd->sep));
-		snprintf(values[5],    48, "%s", SF(nd->modificator));
+		snprintf(values[0], 16, "%d", nd->lloc);
+
+		values[1] = nd->str;
+
+		snprintf(values[2], 16, "%d", nd->keycode);
+		snprintf(values[3], 16, "%s", nd->classname);
+		snprintf(values[4], 255, "%s", SF(nd->sep));
+		snprintf(values[5], 48, "%s", SF(nd->modificator));
 
 		if (nd->keycode == -1)
 			values[2] = NULL;
@@ -270,8 +273,8 @@ plvlex_tokens(PG_FUNCTION_ARGS)
 		values[4] = back_vals[4];
 		values[5] = back_vals[5];
 
-		SRF_RETURN_NEXT (funcctx, result);
+		SRF_RETURN_NEXT(funcctx, result);
 	}
 
-	SRF_RETURN_DONE (funcctx);
+	SRF_RETURN_DONE(funcctx);
 }
