@@ -101,8 +101,8 @@ SELECT utl_file.fopen(utl_file.tmpdir(),'non_existent_file.txt','r');
 
 --Other test cases
 --run this under unprivileged user
-CREATE ROLE test_role_files LOGIN;
-SET ROLE TO test_role_files;
+CREATE ROLE regress_test_role_files LOGIN;
+SET ROLE TO regress_test_role_files;
 
 -- should to fail, unpriviliged user cannot to change utl_file_dir
 INSERT INTO utl_file.utl_file_dir(dir) VALUES('test_tmp_dir');
@@ -139,10 +139,10 @@ DELETE FROM utl_file.utl_file_dir;
 -- reconnect
 \c
 
-SET ROLE TO test_role_files;
+SET ROLE TO regress_test_role_files;
 
 -- use any function from orafce, should not to fail
 SELECT oracle.add_months('2024-05-20', 1);
 
 SET ROLE TO DEFAULT;
-DROP ROLE test_role_files;
+DROP ROLE regress_test_role_files;
