@@ -2,4 +2,5 @@
 set client_min_messages TO error;
 CREATE EXTENSION IF NOT EXISTS orafce;
 GRANT ALL ON SCHEMA public TO public;
-set client_min_messages TO default;
\ No newline at end of file
+SET client_min_messages TO default;
+SET search_path TO public, oracle;
